@@ -8,7 +8,8 @@ Sound* Sound::instance;
 Sound::Sound()
 	:initialized(false)
 	, m_soloud(nullptr)
-{	
+{
+	init();
 }
 
 Sound::~Sound()
@@ -67,7 +68,8 @@ void Sound::unload(char* filename)
 	if (it != m_audioSourcesDict.end())
 	{
 		it->second->stop();
-		delete it->second;		
+		delete it->second;
+		m_audioSourcesDict.erase(it);
 	}
 }
 
