@@ -74,7 +74,10 @@ public:
 	static Sound* Instance()
 	{
 		if (!instance)
-			instance = new Sound;
+		{
+			instance = new Sound();
+		}
+			
 		return instance;
 	}
 };
\ No newline at end of file
