@@ -26,7 +26,7 @@ PyObject* igeSound_str(igeSound_obj* self)
 
 static PyObject* igeSound_Init(igeSound_obj* self)
 {
-	self->sound->init();
+	Sound::Instance()->init();
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -34,7 +34,7 @@ static PyObject* igeSound_Init(igeSound_obj* self)
 
 static PyObject* igeSound_Release(igeSound_obj* self)
 {
-	self->sound->release();
+	Sound::Instance()->release();
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -50,7 +50,7 @@ static PyObject* igeSound_Play(igeSound_obj* self, PyObject* args, PyObject* kwa
 	static char* kwlist[] = { "name", "stream", "loop", "volume", NULL };
 	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s|iif", kwlist, &soundName, &stream, &loop, &volume)) return NULL;
 
-	int handle = self->sound->play(soundName, stream, loop, volume);
+	int handle = Sound::Instance()->play(soundName, stream, loop, volume);
 	return PyLong_FromLong(handle);
 }
 
@@ -60,7 +60,7 @@ static PyObject* igeSound_Stop(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "s", &soundName))
 		return NULL;
 
-	self->sound->stop(soundName);
+	Sound::Instance()->stop(soundName);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -68,7 +68,7 @@ static PyObject* igeSound_Stop(igeSound_obj* self, PyObject* args)
 
 static PyObject* igeSound_StopAll(igeSound_obj* self)
 {
-	self->sound->stopAllSound();
+	Sound::Instance()->stopAllSound();
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -81,7 +81,7 @@ static PyObject* igeSound_Load(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "s|i", &soundName, &stream))
 		return NULL;
 
-	self->sound->load(soundName, stream);
+	Sound::Instance()->load(soundName, stream);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -93,7 +93,7 @@ static PyObject* igeSound_Unload(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "s", &soundName))
 		return NULL;
 
-	self->sound->unload(soundName);
+	Sound::Instance()->unload(soundName);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -101,7 +101,7 @@ static PyObject* igeSound_Unload(igeSound_obj* self, PyObject* args)
 
 static PyObject* igeSound_UnloadUnused(igeSound_obj* self)
 {
-	self->sound->unloadUnused();
+	Sound::Instance()->unloadUnused();
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -114,7 +114,7 @@ static PyObject* igeSound_SetPositon(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "sfff", &soundName, &x, &y, &z))
 		return NULL;
 
-	self->sound->setPositon(soundName, x, y, z);
+	Sound::Instance()->setPositon(soundName, x, y, z);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -127,7 +127,7 @@ static PyObject* igeSound_SetPitch(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "sf", &soundName, &pitch))
 		return NULL;
 
-	self->sound->setPitch(soundName, pitch);
+	Sound::Instance()->setPitch(soundName, pitch);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -140,7 +140,7 @@ static PyObject* igeSound_SetGain(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "sf", &soundName, &gain))
 		return NULL;
 
-	self->sound->setGain(soundName, gain);
+	Sound::Instance()->setGain(soundName, gain);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -153,7 +153,7 @@ static PyObject* igeSound_SetRolloff(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "sf", &soundName, &rolloff))
 		return NULL;
 
-	self->sound->setRolloff(soundName, rolloff);
+	Sound::Instance()->setRolloff(soundName, rolloff);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -165,7 +165,7 @@ static PyObject* igeSound_SetListenerPosition(igeSound_obj* self, PyObject* args
 	if (!PyArg_ParseTuple(args, "fff", &x, &y, &z))
 		return NULL;
 
-	//self->sound->setListenerPosition(x, y, z);
+	//Sound::Instance()->setListenerPosition(x, y, z);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -177,7 +177,7 @@ static PyObject* igeSound_SetListenerOrientation(igeSound_obj* self, PyObject* a
 	if (!PyArg_ParseTuple(args, "ffffff", &xAt, &yAt, &zAt, &xUp, &yUp, &zUp))
 		return NULL;
 
-	//self->sound->setListenerOrientation(xAt, yAt, zAt, xUp, yUp, zUp);
+	//Sound::Instance()->setListenerOrientation(xAt, yAt, zAt, xUp, yUp, zUp);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -191,7 +191,7 @@ static PyObject* igeSound_FadeVolume(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "iff", &handle, &aTo, &aTime))
 		return NULL;
 
-	self->sound->fadeVolume(handle, aTo, aTime);
+	Sound::Instance()->fadeVolume(handle, aTo, aTime);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -204,7 +204,7 @@ static PyObject* igeSound_ScheduleStop(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "if", &handle, &aTime))
 		return NULL;
 
-	self->sound->scheduleStop(handle, aTime);
+	Sound::Instance()->scheduleStop(handle, aTime);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -216,7 +216,7 @@ static PyObject* igeSound_setGlobalVolume(igeSound_obj* self, PyObject* args)
 	if (!PyArg_ParseTuple(args, "f", &volume))
 		return NULL;
 
-	self->sound->setGlobalVolume(volume);
+	Sound::Instance()->setGlobalVolume(volume);
 
 	Py_INCREF(Py_None);
 	return Py_None;
@@ -224,7 +224,7 @@ static PyObject* igeSound_setGlobalVolume(igeSound_obj* self, PyObject* args)
 
 static PyObject* igeSound_getGlobalVolume(igeSound_obj* self)
 {
-	return PyFloat_FromDouble(self->sound->getGlobalVolume());
+	return PyFloat_FromDouble(Sound::Instance()->getGlobalVolume());
 }
 
 PyMethodDef igeSound_methods[] = {
@@ -297,7 +297,7 @@ PyTypeObject IgeSoundType = {
 
 static PyModuleDef igeSound_module = {
 	PyModuleDef_HEAD_INIT,
-	"igeSound.sound",							// Module name to use with Python import statements
+	"igeSound",							// Module name to use with Python import statements
 	"IGE Sound Module.",						// Module description
 	0,
 	igeSound_methods								// Structure that defines the methods of the module
@@ -308,8 +308,5 @@ PyMODINIT_FUNC PyInit_igeSound() {
 
 	if (PyType_Ready(&IgeSoundType) < 0) return NULL;
 
-	Py_INCREF(&IgeSoundType);
-	PyModule_AddObject(module, "sound", (PyObject*)&IgeSoundType);
-
 	return module;
 }
\ No newline at end of file
